@@ -1,4 +1,4 @@
-/* 
+/*
      This file is part of doodle.
      (C) 2004 Christian Grothoff (and other contributing authors)
 
@@ -27,7 +27,7 @@
  * tree.c.  doodle uses GNU getopt and for portability ships with its
  * own version of the getopt code (getopt*).<p>
  *
- * doodle requires libextractor (http://ovmj.org/libextractor/).
+ * doodle requires libextractor (http://gnunet.org/libextractor/).
  */
 
 #include "config.h"
@@ -49,6 +49,7 @@
 #include <langinfo.h>
 
 #include "doodle.h"
+#include "gettext.h"
 #include "getopt.h"
 #include "helper2.h"
 #include "convert.h"
@@ -67,7 +68,7 @@ static void printHelp () {
     { 'b', "build", NULL,
       gettext_noop("build database (default is to search)") },
     { 'B', "binary", "LANG",
-      gettext_noop("use the generic plaintext extractor for the language with the 2-letter language code LANG (use when building database)") }, 
+      gettext_noop("use the generic plaintext extractor for the language with the 2-letter language code LANG (use when building database)") },
     { 'd', "database", "FILENAME",
       gettext_noop("use location FILENAME to store doodle database") },
     { 'e', "extract", NULL,
@@ -81,9 +82,9 @@ static void printHelp () {
     { 'i', "ignore-case", NULL,
       gettext_noop("be case-insensitive (use when searching)") },
     { 'l', "library", "LIBRARY",
-      gettext_noop("load an extractor plugin named LIBRARY") }, 
+      gettext_noop("load an extractor plugin named LIBRARY") },
     { 'L', "log", "FILENAME",
-      gettext_noop("log keywords to a file named FILENAME") }, 
+      gettext_noop("log keywords to a file named FILENAME") },
     { 'n', "nodefault", NULL,
       gettext_noop("do not load default set of extractor plugins") },
     { 'm', "memory", "SIZE",
@@ -100,7 +101,7 @@ static void printHelp () {
   };
   formatHelp(_("doodle [OPTIONS] ([FILENAMES]*|[KEYWORDS]*)"),
 	     _("Index and search meta-data of files."),
-	     help);  
+	     help);
 }
 
 static int do_extract = 0;
@@ -109,7 +110,7 @@ static int do_print   = 0;
 static int do_filenames = 0;
 static int ignore_case = 0;
 static unsigned int do_approx = 0;
-static char * prunepaths = "/tmp /usr/tmp /var/tmp /dev /proc";
+static char * prunepaths = "/tmp /usr/tmp /var/tmp /dev /proc /sys";
 
 /* *************** helper functions **************** */
 
@@ -123,17 +124,17 @@ static void my_log(void * unused,
   va_list args;
   if ( (level == 0) ||
        (verbose && (level == 1)) ||
-       (very_verbose && (level == 2) ) ) {    
+       (very_verbose && (level == 2) ) ) {
     va_start(args, msg);
     vfprintf(stdout, msg, args);
     va_end(args);
-  }    
+  }
 }
 
 static int isPruned(const char * filename) {
   int i;
   int last;
- 
+
   i = strlen(prunepaths);
   last = i;
   while (i > 0) {
@@ -158,7 +159,7 @@ static int isPruned(const char * filename) {
 
 /**
  * @brief closure for do_index
- */ 
+ */
 typedef struct {
   EXTRACTOR_ExtractorList * elist;
   struct DOODLE_SuffixTree * tree;
@@ -173,15 +174,15 @@ static int do_index(const char * filename,
   struct stat sbuf;
 
   if (isPruned(filename))
-    return 0; 
+    return 0;
   j = -1;
-  for (i=DOODLE_getFileCount(dic->tree)-1;i>=0;i--) 
+  for (i=DOODLE_getFileCount(dic->tree)-1;i>=0;i--)
     if (0 == strcmp(filename,
 		    DOODLE_getFileAt(dic->tree,i)->filename)) {
       j = i;
       break;
     }
-  if (j != -1) 
+  if (j != -1)
     return 0; /* already processed */
   if (0 != stat(filename,
 		&sbuf)) {
@@ -248,14 +249,14 @@ static int build(const char * libraries,
     if (verbose)
       printf(_("Loading default set of libextractor plugins.\n"));
     cls.elist = EXTRACTOR_loadDefaultLibraries();
-  } else 
+  } else
     cls.elist = NULL;
   if (libraries != NULL) {
     if (verbose)
       printf(_("Loading libextractor plugins: '%s'\n"),
 	     libraries);
     cls.elist = EXTRACTOR_loadConfigLibraries(cls.elist,
-					      libraries);  
+					      libraries);
   }
   if (cls.elist == NULL) {
     printf(_("Failed to load any libextractor plugins. Aborting.\n"));
@@ -288,7 +289,7 @@ static int build(const char * libraries,
       free(exp);
       break;
     }
-    free(exp);   
+    free(exp);
   }
   EXTRACTOR_removeAll(cls.elist);
   DOODLE_tree_destroy(cls.tree);
@@ -315,7 +316,7 @@ static void printIt(const DOODLE_FileInfo * fileinfo,
   EXTRACTOR_KeywordList * head;
   const char * filename;
   int i;
-  
+
   filename = fileinfo->filename;
   if (isPruned(filename))
     return;
@@ -323,7 +324,7 @@ static void printIt(const DOODLE_FileInfo * fileinfo,
     if (0 == strcmp(filename,
 		    args->filenames_seen[i]))
       return;
-  if (args->seen_count == args->seen_size) {    
+  if (args->seen_count == args->seen_size) {
     GROW(args->filenames_seen,
 	 args->seen_size,
 	 args->seen_size*2 + 128);
@@ -336,7 +337,7 @@ static void printIt(const DOODLE_FileInfo * fileinfo,
       head = EXTRACTOR_removeDuplicateKeywords
 	(head,
 	 EXTRACTOR_DUPLICATES_REMOVE_UNKNOWN);
-    
+
       /* print */
       printf(_("Keywords for matching file '%s':\n"),
 	     filename);
@@ -363,7 +364,7 @@ static int print(const char * dbName) {
   char * ename;
   struct stat buf;
   int ret;
- 
+
  if (dbName == NULL) {
     printf(_("No database specified. Aborting.\n"));
     return -1;
@@ -381,7 +382,7 @@ static int print(const char * dbName) {
 				 NULL,
 				 ename);
   free(ename);
-  if (tree == NULL) 
+  if (tree == NULL)
     return -1;
   ret = DOODLE_tree_dump(stdout,
 			 tree);
@@ -395,7 +396,7 @@ static int search(const char * libraries,
 		  int argc,
 		  char * argv[]) {
   int ret;
-  struct stat buf;  
+  struct stat buf;
   char * ename;
   struct DOODLE_SuffixTree * tree;
   EXTRACTOR_ExtractorList * extractors;
@@ -424,16 +425,16 @@ static int search(const char * libraries,
 				 mem_limit);
 
   free(ename);
-  if (tree == NULL) 
+  if (tree == NULL)
     return -1;
   if (do_extract) {
     if (do_default)
       extractors = EXTRACTOR_loadDefaultLibraries();
-    else 
+    else
       extractors = NULL;
-    if (libraries != NULL) 
+    if (libraries != NULL)
       extractors = EXTRACTOR_loadConfigLibraries(extractors,
-						 libraries);  
+						 libraries);
   } else
     extractors = NULL;
 
@@ -466,7 +467,7 @@ static int search(const char * libraries,
 				  &args)) {
 	printf(_("\tNot found!\n"));
 	ret++;
-      } 
+      }
     } else {
       if (0 == DOODLE_tree_search_approx(tree,
 					 do_approx,
@@ -479,7 +480,7 @@ static int search(const char * libraries,
       }
     }
     free(utf);
-  }  
+  }
   DOODLE_tree_destroy(tree);
   EXTRACTOR_removeAll(extractors);
 
@@ -525,7 +526,7 @@ int main(int argc,
       {"extract", 0, 0, 'e'},
       {"filenames", 0, 0, 'f'} ,
       {"help", 0, 0, 'h'},
-      {"hash", 1, 0, 'H'}, 
+      {"hash", 1, 0, 'H'},
       {"ignore-case", 0, 0, 'i'},
       {"library", 1, 0, 'l'},
       {"log", 1, 0, 'L'},
@@ -539,14 +540,14 @@ int main(int argc,
     };
     option_index = 0;
     c = getopt_long(argc,
-		    argv, "VvhbB:eH:nm:il:L:vd:fa:p", 
-		    long_options, 
+		    argv, "VvhbB:eH:nm:il:L:vd:fa:p",
+		    long_options,
 		    &option_index);
-    
+
     if (c == -1)
       break; /* No more flags to process */
     switch (c) {
-    case 'a': 
+    case 'a':
       if (1 != sscanf(optarg, "%ud", &do_approx)) {
 	printf(_("You must pass a number to the '%s' option.\n"),
 	       "-a");
@@ -577,7 +578,7 @@ int main(int argc,
 	printf(_("The options '%s' and '%s' cannot be used together!\n"),
 	       "-b", "-i");
 	return -1;
-      }    
+      }
       break;
     case 'd':
       dbName = optarg;
@@ -601,14 +602,14 @@ int main(int argc,
 	       "-b", "-i");
 	return -1;
       }
-      break;      
+      break;
     case 'l':
       libraries = optarg;
       break;
     case 'L':
       log = optarg;
       break;
-    case 'm': 
+    case 'm':
       if (1 != sscanf(optarg, "%ud", &mem_limit)) {
 	printf(_("You must pass a number to the '%s' option.\n"),
 	       "-m");
@@ -622,7 +623,7 @@ int main(int argc,
       break;
     case 'n':
       do_default = 0;
-      break;      
+      break;
     case 'p':
       do_print = 1;
       if (do_build == 1) {
@@ -649,25 +650,25 @@ int main(int argc,
       return -1;
     }  /* end of parsing commandline */
   } /* while (1) */
-  
+
   if ( (do_print == 0) &&
-       (argc - optind < 1) ) {    
+       (argc - optind < 1) ) {
     fprintf(stderr,
-	    do_build ? 
+	    do_build ?
 	    _("Invoke with filenames or directories to index!\n") :
 	    _("Invoke with query terms to search for!\n"));
     return -1;
   }
-  
+
   if (libraries != NULL)
     libraries = strdup(libraries);
-  if (binary != NULL) {    
+  if (binary != NULL) {
     if (libraries == NULL)
-      tmp = MALLOC(strlen("libextractor_printable_") + 1 + 
+      tmp = MALLOC(strlen("libextractor_printable_") + 1 +
 		   strlen(binary));
     else
-      tmp = MALLOC(strlen(libraries) + 
-		   strlen(":libextractor_printable_") + 1 + 
+      tmp = MALLOC(strlen(libraries) +
+		   strlen(":libextractor_printable_") + 1 +
 		   strlen(binary));
     if (libraries == NULL) {
       strcpy(tmp, "libextractor_printable_");
@@ -679,15 +680,15 @@ int main(int argc,
     if (libraries != NULL)
       free(libraries);
     libraries = tmp;
-  } 
+  }
 
-  if (hash != NULL) {    
+  if (hash != NULL) {
     if (libraries == NULL)
-      tmp = MALLOC(strlen("libextractor_hash_") + 1 + 
+      tmp = MALLOC(strlen("libextractor_hash_") + 1 +
 		   strlen(hash));
     else
-      tmp = MALLOC(strlen(libraries) + 
-		   strlen(":libextractor_hash_") + 1 + 
+      tmp = MALLOC(strlen(libraries) +
+		   strlen(":libextractor_hash_") + 1 +
 		   strlen(hash));
     if (libraries == NULL) {
       strcpy(tmp, "libextractor_hash_");
@@ -699,7 +700,7 @@ int main(int argc,
     if (libraries != NULL)
       free(libraries);
     libraries = tmp;
-  } 
+  }
 
   if (do_build) {
     ret = build(libraries,
@@ -710,16 +711,16 @@ int main(int argc,
 		&argv[optind]);
     if (libraries != NULL)
       free(libraries);
-    return ret;    
+    return ret;
   } else if (do_print) {
     int i;
     char * name;
-    
+
     ret = 0;
-    name = strdup(dbName);    
+    name = strdup(dbName);
     for (i=strlen(name)-1;i>=0;i--) {
       if (name[i] == ':') {
-	ret += print(&name[i+1]);		 
+	ret += print(&name[i+1]);		
 	name[i] = '\0';
       }
     }
@@ -731,9 +732,9 @@ int main(int argc,
   } else {
     int i;
     char * name;
-    
+
     ret = 0;
-    name = strdup(dbName);    
+    name = strdup(dbName);
     for (i=strlen(name)-1;i>=0;i--) {
       if (name[i] == ':') {
 	ret += search(libraries,
