@@ -1,4 +1,4 @@
-/* 
+/*
      This file is part of doodle.
      (C) 2004 Christian Grothoff (and other contributing authors)
 
@@ -42,6 +42,7 @@
 #include <fam.h>
 #include <locale.h>
 #include "doodle.h"
+#include "gettext.h"
 #include "getopt.h"
 #include "helper2.h"
 #include "semaphore.h"
@@ -57,7 +58,7 @@ static void printHelp () {
   static Help help[] = {
     { 'B', "binary", "LANG",
       gettext_noop("use the generic plaintext extractor"
-		   " for the language with the 2-letter language code LANG") }, 
+		   " for the language with the 2-letter language code LANG") },
     { 'd', "database", "FILENAME",
       gettext_noop("use location FILENAME to store doodle database") },
     { 'D', "debug", NULL,
@@ -69,9 +70,9 @@ static void printHelp () {
     { 'H', "hash", "ALGORITHM",
       gettext_noop("compute hash using the given ALGORITHM") },
     { 'l', "library", "LIBRARY",
-      gettext_noop("load an extractor plugin named LIBRARY") }, 
+      gettext_noop("load an extractor plugin named LIBRARY") },
     { 'L', "log", "FILENAME",
-      gettext_noop("log activity to a file named FILENAME") }, 
+      gettext_noop("log activity to a file named FILENAME") },
     { 'n', "nodefault", NULL,
       gettext_noop("do not load default set of extractor plugins") },
     { 'm', "memory", "SIZE",
@@ -86,20 +87,20 @@ static void printHelp () {
   };
   formatHelp(_("doodled [OPTIONS] [FILENAMES]"),
 	     _("Continuously index files in the background."),
-	     help);  
+	     help);
 }
 
 static int do_debug = 0;
 static int do_default = 1;
 static int do_filenames = 0;
-static char * prunepaths = "/tmp /usr/tmp /var/tmp /dev /proc";
+static char * prunepaths = "/tmp /usr/tmp /var/tmp /dev /proc /sys";
 
 /* *************** helper functions **************** */
 
 static int isPruned(const char * filename) {
   int i;
   int last;
- 
+
   i = strlen(prunepaths);
   last = i;
   while (i > 0) {
@@ -133,18 +134,18 @@ static void my_log(FILE * logfile,
   if ( (0) ||
        (level == 0) ||
        (verbose && (level == 1)) ||
-       (very_verbose && (level == 2) ) ) {    
+       (very_verbose && (level == 2) ) ) {
     va_start(args, msg);
     vfprintf(logfile, msg, args);
     va_end(args);
-  }    
+  }
 }
 
 /* ************** actual functionality code ************* */
 
 /**
  * @brief closure for do_index and other processing functions
- */ 
+ */
 typedef struct {
   EXTRACTOR_ExtractorList * elist;
   struct DOODLE_SuffixTree * tree;
@@ -186,16 +187,16 @@ static void * processEvents(DIC * cls) {
 	   DOODLE_LOG_VERY_VERBOSE,
 	   _("Event processing thread created.\n"));
   while ( (0 == testShutdown()) &&
-	  (cls->continueRunning) ) {     
+	  (cls->continueRunning) ) {
     char * name;
-     
+
     FD_ZERO(&r);
     FD_ZERO(&w);
     FD_ZERO(&e);
     FD_SET(fd, &r);
     i = select(fd+1, &r, &w, &e, NULL);
     if (i == -1) {
-      if (errno == EINTR) 
+      if (errno == EINTR)
 	continue;
       cls->log(cls->logContext,
 	       DOODLE_LOG_CRITICAL,
@@ -213,7 +214,7 @@ static void * processEvents(DIC * cls) {
       sleep(1);
       continue;
     }
-      
+
     MUTEX_LOCK(&cls->lock);
     if (-1 == FAMNextEvent(&cls->fc, &fe)) {
       cls->log(cls->logContext,
@@ -243,12 +244,12 @@ static void * processEvents(DIC * cls) {
       MUTEX_UNLOCK(&cls->lock);
       continue;
     }
-      
-    
+
+
     cls->log(cls->logContext,
 	     DOODLE_LOG_INSANELY_VERBOSE,
 	     "FAM EVENT (%d,%s,%s) on file '%s'.\n",
-	     fe.code, 
+	     fe.code,
 	     fe.userdata,
 	     fe.filename,
 	     name);
@@ -258,8 +259,8 @@ static void * processEvents(DIC * cls) {
     case FAMDeleted:
     case FAMMoved:
     case FAMAcknowledge:
-    case FAMExists: 
-    case FAMEndExist:  
+    case FAMExists:
+    case FAMEndExist:
       GROW(cls->events,
 	   cls->eventCount,
 	   cls->eventCount+1);
@@ -289,9 +290,9 @@ static int do_index(const char * filename,
 		   dic->ename,
 		   strlen(dic->ename)))
     return 0; /* database (and database-temp file) is always pruned! */
-  
+
   if (isPruned(filename))
-    return 0; 
+    return 0;
   for (i=dic->deferredCount-1;i>=0;i--) {
     if (0 == strcmp(filename,
 		    dic->deferredTruncations[i])) {
@@ -312,7 +313,7 @@ static int do_index(const char * filename,
       break;
     }
   }
-  
+
   k = -1;
   for (i=0;i<dic->frPos;i++) {
     if (0 == strcmp(filename,
@@ -335,7 +336,7 @@ static int do_index(const char * filename,
       GROW(dic->deferredTruncations,
 	   dic->deferredCount,
 	   dic->deferredCount + 1);
-      dic->deferredTruncations[dic->deferredCount-1] 
+      dic->deferredTruncations[dic->deferredCount-1]
 	= strdup(filename);
     }
     if (k != -1) {
@@ -354,15 +355,15 @@ static int do_index(const char * filename,
       dic->frNames[dic->frPos-1] = NULL;
       dic->frPos--;
     }
-    return 0;  
-  } 
+    return 0;
+  }
 
   if ( (S_ISDIR(sbuf.st_mode)) &&
 #ifdef S_ISLNK
-       (! S_ISLNK(sbuf.st_mode)) && 
+       (! S_ISLNK(sbuf.st_mode)) &&
 #endif
 #ifdef S_ISSOCK
-       (! S_ISSOCK(sbuf.st_mode)) && 
+       (! S_ISSOCK(sbuf.st_mode)) &&
 #endif
        (k == -1) ) {
     char * fn;
@@ -413,9 +414,9 @@ static int do_index(const char * filename,
       GROW(dic->deferredTruncations,
 	   dic->deferredCount,
 	   dic->deferredCount + 2);
-      dic->deferredTruncations[dic->deferredCount-2] 
+      dic->deferredTruncations[dic->deferredCount-2]
 	= strdup(filename);
-      
+
       DOODLE_tree_truncate_multiple(dic->tree,
 				    (const char**)dic->deferredTruncations);
       for (i=dic->deferredCount-2;i>=0;i--)
@@ -470,7 +471,7 @@ static void * worker(DIC * cls) {
     run_shutdown(0);
     return NULL;
   }
-  
+
   DOODLE_tree_truncate_modified(cls->tree,
 				cls->log,
 				cls->logContext);
@@ -491,7 +492,7 @@ static void * worker(DIC * cls) {
       free(exp);
       break;
     }
-    free(exp);      
+    free(exp);
   }
   DOODLE_tree_destroy(cls->tree);
   cls->treePresent = 0;
@@ -528,7 +529,7 @@ static void * worker(DIC * cls) {
       if (cls->treePresent == 1)
 	cls->tree = DOODLE_tree_create((DOODLE_Logger) cls->log,
 				       cls->logContext,
-				       cls->ename); 
+				       cls->ename);
     }
     MUTEX_UNLOCK(&cls->lock);
     if (fn != NULL) {
@@ -563,7 +564,7 @@ static int build(const char * libraries,
 		 const char * dbName,
 		 size_t mem_limit,
 		 const char * log,
-		 int argc,		 
+		 int argc,		
 		 char * argv[]) {
   int i;
   int ret;
@@ -578,7 +579,7 @@ static int build(const char * libraries,
   cls.argv = argv;
   cls.deferredCount = 0;
   cls.deferredTruncations = NULL;
-  logfile = NULL; 
+  logfile = NULL;
   if (log != NULL) {
     logfile = fopen(log, "w+");
     if (logfile == NULL)
@@ -626,7 +627,7 @@ static int build(const char * libraries,
 	   DOODLE_LOG_VERY_VERBOSE,
 	   _("Loading default set of libextractor plugins.\n"));
     cls.elist = EXTRACTOR_loadDefaultLibraries();
-  } else 
+  } else
     cls.elist = NULL;
   if (libraries != NULL) {
     my_log(logfile,
@@ -634,7 +635,7 @@ static int build(const char * libraries,
 	   _("Loading libextractor plugins: '%s'\n"),
 	   libraries);
     cls.elist = EXTRACTOR_loadConfigLibraries(cls.elist,
-					      libraries);  
+					      libraries);
   }
   if (cls.elist == NULL) {
     my_log(logfile,
@@ -663,7 +664,7 @@ static int build(const char * libraries,
        128);
   ret = 0;
 
-  
+
   MUTEX_CREATE(&cls.lock);
   if (0 != PTHREAD_CREATE(&workerThread,
 			  (PThreadMain)&worker,
@@ -688,7 +689,7 @@ static int build(const char * libraries,
 	   DOODLE_LOG_CRITICAL,
 	   _("No files exist that doodled would monitor for changes.  Exiting.\n"));
   }
-  
+
 
   for (i=0;i<cls.frSize;i++) {
     /* flush fam-event queue */
@@ -704,13 +705,13 @@ static int build(const char * libraries,
     if (cls.frNames[i] != NULL) {
       my_log(logfile,
 	     DOODLE_LOG_VERBOSE,
-	     _("Cancling fam monitor '%s'.\n"),
+	     _("Cancelling fam monitor '%s'.\n"),
 	     cls.frNames[i]);
-      if (-1 == FAMCancelMonitor(&cls.fc, 
+      if (-1 == FAMCancelMonitor(&cls.fc,
 				 &cls.fr[i])) {
 	cls.log(cls.logContext,
 		DOODLE_LOG_CRITICAL,
-		_("Call to '%s' on file '%s' failed: %s\n"),
+		_("Call to '%s' for file '%s' failed: %s\n"),
 		"FAMCancelMonitor",
 		cls.frNames[i],
 		FamErrlist[FAMErrno]);
@@ -734,8 +735,8 @@ static int build(const char * libraries,
   if (0 != FAMClose(&cls.fc)) {
     my_log(logfile,
 	   DOODLE_LOG_CRITICAL,
-	   _("Error disconnecting from fam.\n"));    
-  } 
+	   _("Error disconnecting from fam.\n"));
+  }
   my_log(logfile,
 	 DOODLE_LOG_VERBOSE,
 	 _("Unloading libextractor plugins.\n"));
@@ -758,7 +759,7 @@ static void detachFromTerminal(int * filedes) {
   pid_t pid;
   int nullfd;
 #endif
-  
+
   /* Don't hold the wrong FS mounted */
   if (chdir("/") < 0) {
     perror("chdir");
@@ -775,16 +776,16 @@ static void detachFromTerminal(int * filedes) {
   if (pid) {  /* Parent */
     int ok;
     char c;
-    
+
     close(filedes[1]); /* we only read */
     ok = -1;
     while (0 < read(filedes[0], &c, sizeof(char))) {
-      if (c == '.') 
+      if (c == '.')
 	ok = 0;
-    }      
+    }
     fflush(stdout);
     if (ok == 0)
-      exit(0);   
+      exit(0);
     else
       exit(1); /* child reported error */
   }
@@ -794,13 +795,13 @@ static void detachFromTerminal(int * filedes) {
   if (nullfd < 0) {
     perror("/dev/null");
     exit(1);
-  }   
+  }
   /* child - close fds linking to invoking terminal, but
    * close usual incoming fds, but redirect them somewhere
    * useful so the fds don't get reallocated elsewhere.
    */
-  if (dup2(nullfd,0) < 0 || 
-      dup2(nullfd,1) < 0 || 
+  if (dup2(nullfd,0) < 0 ||
+      dup2(nullfd,1) < 0 ||
       dup2(nullfd,2) < 0) {
     perror("dup2"); /* Should never happen */
     exit(1);
@@ -851,7 +852,7 @@ int main(int argc,
       {"debug", 0, 0, 'D'},
       {"filenames", 0, 0, 'f'} ,
       {"help", 0, 0, 'h'},
-      {"hash", 1, 0, 'H'}, 
+      {"hash", 1, 0, 'H'},
       {"library", 1, 0, 'l'},
       {"log", 1, 0, 'L'},
       {"memory", 1, 0, 'm'},
@@ -863,10 +864,10 @@ int main(int argc,
     };
     option_index = 0;
     c = getopt_long(argc,
-		    argv, "B:d:DfhH:l:L:m:nP:vV", 
-		    long_options, 
+		    argv, "B:d:DfhH:l:L:m:nP:vV",
+		    long_options,
 		    &option_index);
-    
+
     if (c == -1)
       break; /* No more flags to process */
     switch (c) {
@@ -894,7 +895,7 @@ int main(int argc,
     case 'L':
       log = optarg;
       break;
-    case 'm': 
+    case 'm':
       if (1 != sscanf(optarg, "%ud", &mem_limit)) {
 	printf(_("You must pass a number to the '%s' option.\n"),
 	       "-m");
@@ -908,7 +909,7 @@ int main(int argc,
       break;
     case 'n':
       do_default = 0;
-      break;      
+      break;
     case 'P':
       prunepaths = optarg;
       break;
@@ -927,22 +928,22 @@ int main(int argc,
       return -1;
     }  /* end of parsing commandline */
   } /* while (1) */
-  
-  if (argc - optind < 1) {    
+
+  if (argc - optind < 1) {
     fprintf(stderr,
 	    _("Invoke with filenames or directories to monitor!\n"));
     return -1;
   }
-  
+
   if (libraries != NULL)
     libraries = strdup(libraries);
-  if (binary != NULL) {    
+  if (binary != NULL) {
     if (libraries == NULL)
-      tmp = MALLOC(strlen("libextractor_printable_") + 1 + 
+      tmp = MALLOC(strlen("libextractor_printable_") + 1 +
 		   strlen(binary));
     else
-      tmp = MALLOC(strlen(libraries) + 
-		   strlen(":libextractor_printable_") + 1 + 
+      tmp = MALLOC(strlen(libraries) +
+		   strlen(":libextractor_printable_") + 1 +
 		   strlen(binary));
     if (libraries == NULL) {
       strcpy(tmp, "libextractor_printable_");
@@ -954,15 +955,15 @@ int main(int argc,
     if (libraries != NULL)
       free(libraries);
     libraries = tmp;
-  } 
+  }
 
-  if (hash != NULL) {    
+  if (hash != NULL) {
     if (libraries == NULL)
-      tmp = MALLOC(strlen("libextractor_hash_") + 1 + 
+      tmp = MALLOC(strlen("libextractor_hash_") + 1 +
 		   strlen(hash));
     else
-      tmp = MALLOC(strlen(libraries) + 
-		   strlen(":libextractor_hash_") + 1 + 
+      tmp = MALLOC(strlen(libraries) +
+		   strlen(":libextractor_hash_") + 1 +
 		   strlen(hash));
     if (libraries == NULL) {
       strcpy(tmp, "libextractor_hash_");
@@ -974,8 +975,8 @@ int main(int argc,
     if (libraries != NULL)
       free(libraries);
     libraries = tmp;
-  } 
-  
+  }
+
   if (do_debug == 0)
     detachFromTerminal(filedes);
   initializeShutdownHandlers();
@@ -987,11 +988,11 @@ int main(int argc,
 	      mem_limit,
 	      log,
 	      argc - optind,
-	      &argv[optind]); 
+	      &argv[optind]);
   doneShutdownHandlers();
   if (libraries != NULL)
     free(libraries);
-  return ret;    
+  return ret;
 }
 
 /* end of doodled.c */
